package com.cmx.hydrology.activity

import android.Manifest
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Build
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.annotation.RequiresApi
import androidx.core.app.ActivityCompat
import com.cmx.hydrology.databinding.ActivityLoginBinding
import com.cmx.hydrology.model.LoginBean
import com.cmx.hydrology.model.LoginRes
import com.cmx.hydrology.retrofit.RetrofitAPIManager
import com.cmx.hydrology.utils.MyUtils
import com.cmx.hydrology.utils.SpUtils
import es.dmoral.toasty.Toasty
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class LoginActivity : BaseActivity() {
    private var binding: ActivityLoginBinding? = null
    private val REQUIRED_PERMISSION_LIST = arrayOf(
        Manifest.permission.WRITE_EXTERNAL_STORAGE,
        Manifest.permission.ACCESS_COARSE_LOCATION,
        Manifest.permission.ACCESS_FINE_LOCATION
    )
    private val REQUEST_PERMISSION_CODE = 99
    private var allPermission = true


    @RequiresApi(api = Build.VERSION_CODES.M)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityLoginBinding.inflate(layoutInflater)
        setContentView(binding!!.root)
        MyUtils.setFullscreen(this, true, true)
        checkAllPermission()
        binding!!.btnLogin.setOnClickListener(View.OnClickListener {
            if (TextUtils.isEmpty(binding!!.edtUsername.text.toString().trim { it <= ' ' })) {
                Toasty.info(this@LoginActivity, "请输入用户名").show()
                return@OnClickListener
            }
            if (TextUtils.isEmpty(binding!!.edtPassword.text.toString().trim { it <= ' ' })) {
                Toasty.info(this@LoginActivity, "请输入密码").show()
                return@OnClickListener
            }
            toLogin()
        })
    }

    /**
     * 登录
     */
    private fun toLogin() {
        showDialog()
        val LoginBean = LoginBean()
        LoginBean.username = binding!!.edtUsername.text.toString().trim { it <= ' ' }
        LoginBean.password = binding!!.edtPassword.text.toString().trim { it <= ' ' }
        val call = RetrofitAPIManager.provideClientApi().login(LoginBean)
        call!!.enqueue(object : Callback<LoginRes?> {
            override fun onResponse(call: Call<LoginRes?>, response: Response<LoginRes?>) {
                disDialog()
                if (response.isSuccessful && response.body()!!.code == 0) {
                    SpUtils.putString(this@LoginActivity, "token", response.body()!!.access_token)
                    val intent = Intent(this@LoginActivity, MainActivity::class.java)
                    startActivity(intent)
                    finish()
                } else {
                    Toasty.error(this@LoginActivity, response.body()!!.message!!).show()
                }
            }

            override fun onFailure(call: Call<LoginRes?>, t: Throwable) {
                disDialog()
                Toasty.info(this@LoginActivity, "登录失败").show()
            }
        })
    }

    public override fun onDestroy() {
        super.onDestroy()
        binding = null
    }

    /**
     * 权限检查
     */
    private fun checkAllPermission() {
        ActivityCompat.requestPermissions(this, REQUIRED_PERMISSION_LIST, REQUEST_PERMISSION_CODE)
    }

    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String?>, grantResults: IntArray) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == REQUEST_PERMISSION_CODE) {
            for (i in grantResults.indices.reversed()) {
                if (grantResults[i] != PackageManager.PERMISSION_GRANTED) {
                    allPermission = false
                }
            }
            if (!allPermission) {
                Toasty.info(this, "权限已拒绝，请手动开启!").show()
                finish()
            }
        }
    }

}