package com.cmx.hydrology.activity

import android.content.Intent
import android.os.Build
import android.os.Bundle
import android.view.View
import androidx.annotation.RequiresApi
import androidx.navigation.NavController
import androidx.navigation.Navigation
import androidx.navigation.ui.NavigationUI
import com.cmx.hydrology.R
import com.cmx.hydrology.constant.Events
import com.cmx.hydrology.databinding.ActivityMainBinding
import com.google.android.material.bottomnavigation.BottomNavigationView
import com.lsxiao.apollo.core.Apollo
import com.lsxiao.apollo.core.annotations.Receive
import kotlinx.android.synthetic.main.activity_main.nav_view

class MainActivity : BaseActivity() {

    private var navController: NavController? = null

    @RequiresApi(api = Build.VERSION_CODES.M)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
        navController = Navigation.findNavController(this, R.id.nav_host_fragment_activity_main)
        NavigationUI.setupWithNavController(nav_view, navController!!)
        nav_view.itemIconTintList = null
    }

    /**
     * 显示tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_SHOW)
    fun showTab() {
        nav_view.visibility = View.VISIBLE
    }

    /**
     * 隐藏tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_HIDE)
    fun hideTab() {
        nav_view.visibility = View.GONE
    }

    /**
     * 打开新的web
     */
    @Receive(Events.JS_OPEN_OPEN_WEB)
    fun openWeb(url: String?) {
        val intent = Intent(this, WebActivity::class.java)
        intent.putExtra("url", url)
        startActivity(intent)
    }

    /**
     * 选择tab
     */
    @Receive(Events.JS_OPEN_TAB)
    fun ckTab(mode: String?) {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB)
        when (mode) {
            "1" -> {
                val menu = nav_view!!.menu
                val menuItem = menu.getItem(0) // 将index替换为您想要点击的项目的索引
                menuItem.isChecked = true
                navController!!.navigate(R.id.navigation_home)
            }

            "2" -> {
                val menu2 = nav_view!!.menu
                val menuItem2 = menu2.getItem(1) // 将index替换为您想要点击的项目的索引
                menuItem2.isChecked = true
                navController!!.navigate(R.id.navigation_msg)
            }

            "3" -> {
                val menu3 = nav_view!!.menu
                val menuItem3 = menu3.getItem(2) // 将index替换为您想要点击的项目的索引
                menuItem3.isChecked = true
                navController!!.navigate(R.id.navigation_map)
            }

            "4" -> {
                val menu4 = nav_view!!.menu
                val menuItem4 = menu4.getItem(3) // 将index替换为您想要点击的项目的索引
                menuItem4.isChecked = true
                navController!!.navigate(R.id.navigation_my)
            }
        }
    }

    /**
     * 退出登录
     */
    @Receive(Events.JS_OPEN_LOGOUT)
    fun exit() {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB)
        finish()
        val intent = Intent(this, LoginActivity::class.java)
        startActivity(intent)
    }
}